@@ -67,8 +67,9 @@ public class Expand extends Task {
     private Union resources = new Union();
     private boolean resourcesSpecified = false;
     private boolean failOnEmptyArchive = false;
-    private boolean stripAbsolutePathSpec = false;
+    private boolean stripAbsolutePathSpec = true;
     private boolean scanForUnicodeExtraFields = true;
+    private Boolean allowFilesToEscapeDest = null;
 
     public static final String NATIVE_ENCODING = "native-encoding";
 
@@ -88,6 +89,7 @@ public class Expand extends Task {
     /**
      * Creates an Expand instance and sets the given encoding.
      *
+     * @param encoding String
      * @since Ant 1.9.5
      */
     protected Expand(String encoding) {
@@ -97,6 +99,7 @@ public class Expand extends Task {
     /**
      * Whether try ing to expand an empty archive would be an error.
      *
+     * @param b boolean
      * @since Ant 1.8.0
      */
     public void setFailOnEmptyArchive(boolean b) {
@@ -106,6 +109,7 @@ public class Expand extends Task {
     /**
      * Whether try ing to expand an empty archive would be an error.
      *
+     * @return boolean
      * @since Ant 1.8.0
      */
     public boolean getFailOnEmptyArchive() {
@@ -191,7 +195,7 @@ public class Expand extends Task {
                 log("extracting " + ze.getName(), Project.MSG_DEBUG);
                 try {
                     extractFile(fileUtils, srcF, dir,
-                                is = zf.getInputStream(ze),
+                                is = zf.getInputStream(ze), //NOSONAR
                                 ze.getName(), new Date(ze.getTime()),
                                 ze.isDirectory(), mapper);
                 } finally {
@@ -256,14 +260,17 @@ public class Expand extends Task {
                                boolean isDirectory, FileNameMapper mapper)
                                throws IOException {
 
-        if (stripAbsolutePathSpec && entryName.length() > 0
+        final boolean entryNameStartsWithPathSpec = entryName.length() > 0
             && (entryName.charAt(0) == File.separatorChar
                 || entryName.charAt(0) == '/'
-                || entryName.charAt(0) == '\\')) {
+                || entryName.charAt(0) == '\\');
+        if (stripAbsolutePathSpec && entryNameStartsWithPathSpec) {
             log("stripped absolute path spec from " + entryName,
                 Project.MSG_VERBOSE);
             entryName = entryName.substring(1);
         }
+        boolean allowedOutsideOfDest = Boolean.TRUE == getAllowFilesToEscapeDest()
+            || null == getAllowFilesToEscapeDest() && !stripAbsolutePathSpec && entryNameStartsWithPathSpec;
 
         if (patternsets != null && patternsets.size() > 0) {
             String name = entryName.replace('/', File.separatorChar)
@@ -272,18 +279,16 @@ public class Expand extends Task {
             boolean included = false;
             Set<String> includePatterns = new HashSet<String>();
             Set<String> excludePatterns = new HashSet<String>();
-            final int size = patternsets.size();
-            for (int v = 0; v < size; v++) {
-                PatternSet p = patternsets.elementAt(v);
+            for (PatternSet p : patternsets) {
                 String[] incls = p.getIncludePatterns(getProject());
                 if (incls == null || incls.length == 0) {
                     // no include pattern implicitly means includes="**"
-                    incls = new String[] {"**"};
+                    incls = new String[]{"**"};
                 }
 
-                for (int w = 0; w < incls.length; w++) {
-                    String pattern = incls[w].replace('/', File.separatorChar)
-                        .replace('\\', File.separatorChar);
+                for (String incl : incls) {
+                    String pattern = incl.replace('/', File.separatorChar)
+                            .replace('\\', File.separatorChar);
                     if (pattern.endsWith(File.separator)) {
                         pattern += "**";
                     }
@@ -292,10 +297,9 @@ public class Expand extends Task {
 
                 String[] excls = p.getExcludePatterns(getProject());
                 if (excls != null) {
-                    for (int w = 0; w < excls.length; w++) {
-                        String pattern = excls[w]
-                            .replace('/', File.separatorChar)
-                            .replace('\\', File.separatorChar);
+                    for (String excl : excls) {
+                        String pattern = excl.replace('/', File.separatorChar)
+                                .replace('\\', File.separatorChar);
                         if (pattern.endsWith(File.separator)) {
                             pattern += "**";
                         }
@@ -329,6 +333,12 @@ public class Expand extends Task {
             mappedNames = new String[] {entryName};
         }
         File f = fileUtils.resolveFile(dir, mappedNames[0]);
+        if (!allowedOutsideOfDest && !fileUtils.isLeadingPath(dir, f)) {
+            log("skipping " + entryName + " as its target " + f + " is outside of "
+                + dir + ".", Project.MSG_VERBOSE);
+                return;
+        }
+
         try {
             if (!overwrite && f.exists()
                 && f.lastModified() >= entryDate.getTime()) {
@@ -472,6 +482,7 @@ public class Expand extends Task {
      * where the child-class doesn't (i.e. Unzip in the compress
      * Antlib).
      *
+     * @param encoding String
      * @since Ant 1.8.0
      */
     protected void internalSetEncoding(String encoding) {
@@ -482,6 +493,7 @@ public class Expand extends Task {
     }
 
     /**
+     * @return String
      * @since Ant 1.8.0
      */
     public String getEncoding() {
@@ -491,6 +503,7 @@ public class Expand extends Task {
     /**
      * Whether leading path separators should be stripped.
      *
+     * @param b boolean
      * @since Ant 1.8.0
      */
     public void setStripAbsolutePathSpec(boolean b) {
@@ -500,6 +513,7 @@ public class Expand extends Task {
     /**
      * Whether unicode extra fields will be used if present.
      *
+     * @param b boolean
      * @since Ant 1.8.0
      */
     public void setScanForUnicodeExtraFields(boolean b) {
@@ -511,6 +525,7 @@ public class Expand extends Task {
      * where the child-class doesn't (i.e. Unzip in the compress
      * Antlib).
      *
+     * @param b boolean
      * @since Ant 1.8.0
      */
     protected void internalSetScanForUnicodeExtraFields(boolean b) {
@@ -518,10 +533,32 @@ public class Expand extends Task {
     }
 
     /**
+     * @return boolean
      * @since Ant 1.8.0
      */
     public boolean getScanForUnicodeExtraFields() {
         return scanForUnicodeExtraFields;
     }
 
+    /**
+     * Whether to allow the extracted file or directory to be outside of the dest directory.
+     *
+     * @param b the flag
+     * @since Ant 1.9.12
+     */
+    public void setAllowFilesToEscapeDest(boolean b) {
+        allowFilesToEscapeDest = b;
+    }
+
+    /**
+     * Whether to allow the extracted file or directory to be outside of the dest directory.
+     *
+     * @return {@code null} if the flag hasn't been set explicitly,
+     * otherwise the value set by the user.
+     * @since Ant 1.9.12
+     */
+    public Boolean getAllowFilesToEscapeDest() {
+        return allowFilesToEscapeDest;
+    }
+
 }
