@@ -19,7 +19,6 @@
 package org.apache.tools.ant.taskdefs;
 
 import java.io.File;
-import java.io.FileNotFoundException;
 import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
@@ -318,6 +317,7 @@ public class Get extends Task {
 
     /**
      * Adds URLs to get.
+     * @param rc ResourceCollection
      * @since Ant 1.8.0
      */
     public void add(final ResourceCollection rc) {
@@ -348,7 +348,7 @@ public class Get extends Task {
      * @param v if "true" then be quiet
      * @since Ant 1.9.4
      */
-    public void setQuiet(final boolean v){
+    public void setQuiet(final boolean v) {
         this.quiet = v;
     }
 
@@ -406,6 +406,7 @@ public class Get extends Task {
      * The time in seconds the download is allowed to take before
      * being terminated.
      *
+     * @param maxTime long
      * @since Ant 1.8.0
      */
     public void setMaxTime(final long maxTime) {
@@ -420,7 +421,6 @@ public class Get extends Task {
      * reach the URI at all.</p>
      *
      * @param r number of attempts to make
-     *
      * @since Ant 1.8.0
      */
     public void setRetries(final int r) {
@@ -436,7 +436,6 @@ public class Get extends Task {
      * Skip files that already exist locally.
      *
      * @param s "true" to skip existing destination files
-     *
      * @since Ant 1.8.0
      */
     public void setSkipExisting(final boolean s) {
@@ -449,6 +448,7 @@ public class Get extends Task {
      * the value is considered unset and the behaviour falls
      * back to the default of the http API.
      *
+     * @param userAgent String
      * @since Ant 1.9.3
      */
     public void setUserAgent(final String userAgent) {
@@ -463,6 +463,7 @@ public class Get extends Task {
      * <p>Defaults to true (allow caching, which is also the
      * HttpUrlConnection default value.</p>
      *
+     * @param httpUseCache boolean
      * @since Ant 1.8.0
      */
     public void setHttpUseCaches(final boolean httpUseCache) {
@@ -476,6 +477,7 @@ public class Get extends Task {
      * <p>Setting this to true also means Ant will uncompress
      * <code>.tar.gz</code> and similar files automatically.</p>
      *
+     * @param b boolean
      * @since Ant 1.9.5
      */
     public void setTryGzipEncoding(boolean b) {
@@ -623,8 +625,8 @@ public class Get extends Task {
         private int redirections = 0;
         private String userAgent = null;
 
-        GetThread(final URL source, final File dest,
-                  final boolean h, final long t, final DownloadProgress p, final int l, final String userAgent) {
+        GetThread(final URL source, final File dest, final boolean h,
+                  final long t, final DownloadProgress p, final int l, final String userAgent) {
             this.source = source;
             this.dest = dest;
             hasTimestamp = h;
@@ -667,34 +669,29 @@ public class Get extends Task {
 
 
         private boolean redirectionAllowed(final URL aSource, final URL aDest) {
-            if (!(aSource.getProtocol().equals(aDest.getProtocol()) || (HTTP
-                    .equals(aSource.getProtocol()) && HTTPS.equals(aDest
-                    .getProtocol())))) {
-                final String message = "Redirection detected from "
-                        + aSource.getProtocol() + " to " + aDest.getProtocol()
-                        + ". Protocol switch unsafe, not allowed.";
-                if (ignoreErrors) {
-                    log(message, logLevel);
-                    return false;
-                } else {
+            if (aSource.getProtocol().equals(aDest.getProtocol())
+                    && (HTTP.equals(aSource.getProtocol()) || HTTPS.equals(aDest.getProtocol()))) {
+                redirections++;
+                if (redirections > REDIRECT_LIMIT) {
+                    final String message = "More than " + REDIRECT_LIMIT
+                            + " times redirected, giving up";
+                    if (ignoreErrors) {
+                        log(message, logLevel);
+                        return false;
+                    }
                     throw new BuildException(message);
                 }
+                return true;
             }
 
-            redirections++;
-            if (redirections > REDIRECT_LIMIT) {
-                final String message = "More than " + REDIRECT_LIMIT
-                        + " times redirected, giving up";
-                if (ignoreErrors) {
-                    log(message, logLevel);
-                    return false;
-                } else {
-                    throw new BuildException(message);
-                }
+            final String message = "Redirection detected from "
+                    + aSource.getProtocol() + " to " + aDest.getProtocol()
+                    + ". Protocol switch unsafe, not allowed.";
+            if (ignoreErrors) {
+                log(message, logLevel);
+                return false;
             }
-
-
-            return true;
+            throw new BuildException(message);
         }
 
         private URLConnection openConnection(final URL aSource) throws IOException {
@@ -718,8 +715,7 @@ public class Get extends Task {
                 // testing
                 final Base64Converter encoder = new Base64Converter();
                 encoding = encoder.encode(up.getBytes());
-                connection.setRequestProperty("Authorization", "Basic "
-                        + encoding);
+                connection.setRequestProperty("Authorization", "Basic " + encoding);
             }
 
             if (tryGzipEncoding) {
@@ -727,10 +723,8 @@ public class Get extends Task {
             }
 
             if (connection instanceof HttpURLConnection) {
-                ((HttpURLConnection) connection)
-                        .setInstanceFollowRedirects(false);
-                ((HttpURLConnection) connection)
-                        .setUseCaches(httpUseCaches);
+                ((HttpURLConnection) connection).setInstanceFollowRedirects(false);
+                connection.setUseCaches(httpUseCaches);
             }
             // connect to the remote site (may take some time)
             try {
@@ -788,14 +782,13 @@ public class Get extends Task {
         }
 
         private boolean isMoved(final int responseCode) {
-            return responseCode == HttpURLConnection.HTTP_MOVED_PERM ||
-                responseCode == HttpURLConnection.HTTP_MOVED_TEMP ||
-                responseCode == HttpURLConnection.HTTP_SEE_OTHER ||
-                responseCode == HTTP_MOVED_TEMP;
+            return responseCode == HttpURLConnection.HTTP_MOVED_PERM
+                    || responseCode == HttpURLConnection.HTTP_MOVED_TEMP
+                    || responseCode == HttpURLConnection.HTTP_SEE_OTHER
+                    || responseCode == HTTP_MOVED_TEMP;
         }
 
-        private boolean downloadFile()
-                throws FileNotFoundException, IOException {
+        private boolean downloadFile() throws IOException {
             for (int i = 0; i < numberRetries; i++) {
                 // this three attempt trick is to get round quirks in different
                 // Java implementations. Some of them take a few goes to bind
@@ -852,9 +845,7 @@ public class Get extends Task {
             if (verbose)  {
                 final Date t = new Date(remoteTimestamp);
                 log("last modified = " + t.toString()
-                    + ((remoteTimestamp == 0)
-                       ? " - using current time instead"
-                       : ""), logLevel);
+                    + ((remoteTimestamp == 0) ? " - using current time instead" : ""), logLevel);
             }
             if (remoteTimestamp != 0) {
                 FILE_UTILS.setFileLastModified(dest, remoteTimestamp);
@@ -864,7 +855,7 @@ public class Get extends Task {
         /**
          * Has the download completed successfully?
          *
-         * <p>Re-throws any exception caught during executaion.</p>
+         * <p>Re-throws any exception caught during execution.</p>
          */
         boolean wasSuccessful() throws IOException, BuildException {
             if (ioexception != null) {
