@@ -31,7 +31,10 @@ import java.io.OutputStreamWriter;
 import java.io.Reader;
 import java.io.Writer;
 import java.util.ArrayList;
+import java.util.Collections;
+import java.util.Comparator;
 import java.util.Iterator;
+import java.util.List;
 import java.util.Properties;
 
 import org.apache.tools.ant.BuildException;
@@ -67,7 +70,7 @@ public class Replace extends MatchingTask {
     private Resource propertyResource = null;
     private Resource replaceFilterResource = null;
     private Properties properties = null;
-    private ArrayList replacefilters = new ArrayList();
+    private ArrayList<Replacefilter> replacefilters = new ArrayList<Replacefilter>();
 
     private File dir = null;
 
@@ -99,6 +102,7 @@ public class Replace extends MatchingTask {
          * expanded already so you do <b>not</b> want to set this to
          * true.</p>
          *
+         * @param b boolean
          * @since Ant 1.8.0
          */
         public void setExpandProperties(boolean b) {
@@ -287,7 +291,7 @@ public class Replace extends MatchingTask {
          * The filter expects from the component providing the input that data
          * is only added by that component to the end of this StringBuffer.
          * This StringBuffer will be modified by this filter, and expects that
-         * another component will only apped to this StringBuffer.
+         * another component will only added to this StringBuffer.
          * @param input The input for this filter.
          */
         void setInputBuffer(StringBuffer input) {
@@ -508,9 +512,9 @@ public class Replace extends MatchingTask {
         try {
             if (replaceFilterResource != null) {
                 Properties props = getProperties(replaceFilterResource);
-                Iterator e = props.keySet().iterator();
+                Iterator e = getOrderedIterator(props);
                 while (e.hasNext()) {
-                    String tok =  e.next().toString();
+                    String tok = e.next().toString();
                     Replacefilter replaceFilter = createReplacefilter();
                     replaceFilter.setToken(tok);
                     replaceFilter.setValue(props.getProperty(tok));
@@ -740,9 +744,7 @@ public class Replace extends MatchingTask {
      */
     private StringBuffer buildFilterChain(StringBuffer inputBuffer) {
         StringBuffer buf = inputBuffer;
-        final int size = replacefilters.size();
-        for (int i = 0; i < size; i++) {
-            Replacefilter filter = (Replacefilter) replacefilters.get(i);
+        for (Replacefilter filter : replacefilters) {
             filter.setInputBuffer(buf);
             buf = filter.getOutputBuffer();
         }
@@ -897,6 +899,7 @@ public class Replace extends MatchingTask {
     /**
      * Support arbitrary file system based resource collections.
      *
+     * @param rc ResourceCollection
      * @since Ant 1.8.0
      */
     public void addConfigured(ResourceCollection rc) {
@@ -913,6 +916,7 @@ public class Replace extends MatchingTask {
      * Whether the file timestamp shall be preserved even if the file
      * is modified.
      *
+     * @param b boolean
      * @since Ant 1.8.0
      */
     public void setPreserveLastModified(boolean b) {
@@ -922,6 +926,7 @@ public class Replace extends MatchingTask {
     /**
      * Whether the build should fail if nothing has been replaced.
      *
+     * @param b boolean
      * @since Ant 1.8.0
      */
     public void setFailOnNoReplacements(boolean b) {
@@ -941,6 +946,10 @@ public class Replace extends MatchingTask {
 
     /**
      * Replace occurrences of str1 in StringBuffer str with str2.
+     *
+     * @param str StringBuilder
+     * @param str1 String
+     * @param str2 String
      */
     private void stringReplace(StringBuffer str, String str1, String str2) {
         int found = str.indexOf(str1);
@@ -952,4 +961,24 @@ public class Replace extends MatchingTask {
         }
     }
 
+    /**
+     * Sort keys by size so that tokens that are substrings of other
+     * strings are tried later.
+     *
+     * @param props Properties
+     */
+    private Iterator<Object> getOrderedIterator(Properties props) {
+        List<Object> keys = new ArrayList<Object>(props.keySet());
+        Collections.sort(keys, new Comparator<Object>() {
+                //Override annotation is not supported as long as we want to support building Ant on Java 1.5
+                public int compare(Object key1, Object key2) {
+                    return compare(key1.toString(), key2.toString());
+                }
+
+                private int compare(String key1, String key2) {
+                    return key2.length() - key1.length();
+                }
+            });
+        return keys.iterator();
+    }
 }
