@@ -80,9 +80,7 @@ public class VmsCommandLauncher extends Java13CommandLauncher {
     public Process exec(Project project, String[] cmd, String[] env,
                         File workingDir) throws IOException {
         File cmdFile = createCommandFile(cmd, env);
-        Process p = super.exec(project, new String[] {
-                cmdFile.getPath()
-            }, env, workingDir);
+        Process p = super.exec(project, new String[] {cmdFile.getPath()}, env, workingDir);
         deleteAfter(cmdFile, p);
         return p;
     }
@@ -105,13 +103,13 @@ public class VmsCommandLauncher extends Java13CommandLauncher {
             // add the environment as logicals to the DCL script
             if (env != null) {
                 int eqIndex;
-                for (int i = 0; i < env.length; i++) {
-                    eqIndex = env[i].indexOf('=');
+                for (String variable : env) {
+                    eqIndex = variable.indexOf('=');
                     if (eqIndex != -1) {
                         out.write("$ DEFINE/NOLOG ");
-                        out.write(env[i].substring(0, eqIndex));
+                        out.write(variable.substring(0, eqIndex));
                         out.write(" \"");
-                        out.write(env[i].substring(eqIndex + 1));
+                        out.write(variable.substring(eqIndex + 1));
                         out.write('\"');
                         out.newLine();
                     }
