@@ -91,7 +91,7 @@ public class FTPTaskMirrorImpl implements FTPTaskMirror {
 
         /**
          * creates a proxy to a FTP file
-         * @param file
+         * @param file FTPFile
          */
         public FTPFileProxy(FTPFile file) {
             super(file.getName());
@@ -291,10 +291,10 @@ public class FTPTaskMirrorImpl implements FTPTaskMirror {
             Hashtable newroots = new Hashtable();
             // put in the newroots vector the include patterns without
             // wildcard tokens
-            for (int icounter = 0; icounter < includes.length; icounter++) {
+            for (String include : includes) {
                 String newpattern =
-                    SelectorUtils.rtrimWildcardTokens(includes[icounter]);
-                newroots.put(newpattern, includes[icounter]);
+                        SelectorUtils.rtrimWildcardTokens(include);
+                newroots.put(newpattern, include);
             }
             if (task.getRemotedir() == null) {
                 try {
@@ -337,7 +337,7 @@ public class FTPTaskMirrorImpl implements FTPTaskMirror {
                             try {
                                 path = myfile.getRelativePath();
                                 traversesSymlinks = myfile.isTraverseSymlinks();
-                            }  catch (IOException be) {
+                            } catch (IOException be) {
                                 throw new BuildException(be, task.getLocation());
                             } catch (BuildException be) {
                                 isOK = false;
@@ -412,11 +412,10 @@ public class FTPTaskMirrorImpl implements FTPTaskMirror {
                     ftp.changeToParentDirectory();
                     return;
                 }
-                for (int i = 0; i < newfiles.length; i++) {
-                    FTPFile file = newfiles[i];
+                for (FTPFile file : newfiles) {
                     if (file != null
-                        && !file.getName().equals(".")
-                        && !file.getName().equals("..")) {
+                            && !".".equals(file.getName())
+                            && !"..".equals(file.getName())) {
                         String name = vpath + file.getName();
                         scannedDirs.put(name, new FTPFileProxy(file));
                         if (isFunctioningAsDirectory(ftp, dir, file)) {
@@ -426,7 +425,7 @@ public class FTPTaskMirrorImpl implements FTPTaskMirror {
                                 slowScanAllowed = false;
                             } else if (isIncluded(name)) {
                                 accountForIncludedDir(name,
-                                                      new AntFTPFile(ftp, file, completePath) , fast);
+                                        new AntFTPFile(ftp, file, completePath), fast);
                             } else {
                                 dirsNotIncluded.addElement(name);
                                 if (fast && couldHoldIncluded(name)) {
@@ -479,12 +478,10 @@ public class FTPTaskMirrorImpl implements FTPTaskMirror {
          * @param name path of the directory relative to the directory of
          * the fileset
          * @param file directory as file
-         * @param fast
+         * @param fast boolean
          */
         private void accountForIncludedDir(String name, AntFTPFile file, boolean fast) {
-            if (!dirsIncluded.contains(name)
-                && !dirsExcluded.contains(name)) {
-
+            if (!dirsIncluded.contains(name) && !dirsExcluded.contains(name)) {
                 if (!isExcluded(name)) {
                     if (fast) {
                         if (file.isSymbolicLink()) {
@@ -648,7 +645,7 @@ public class FTPTaskMirrorImpl implements FTPTaskMirror {
                     try {
                         ftp.changeWorkingDirectory(directory);
                     } catch (IOException ioe) {
-                        throw new BuildException(ioe, task.getLocation());
+                        throw new BuildException(ioe, task.getLocation()); //NOSONAR
                     }
                 }
                 task.log("remote system is case sensitive : "
@@ -658,14 +655,14 @@ public class FTPTaskMirrorImpl implements FTPTaskMirror {
             }
         }
         private String fiddleName(String origin) {
-            StringBuffer result = new StringBuffer();
-            for (int icounter = 0; icounter < origin.length(); icounter++) {
-                if (Character.isLowerCase(origin.charAt(icounter))) {
-                    result.append(Character.toUpperCase(origin.charAt(icounter)));
-                } else if (Character.isUpperCase(origin.charAt(icounter))) {
-                    result.append(Character.toLowerCase(origin.charAt(icounter)));
+            StringBuilder result = new StringBuilder();
+            for (char ch : origin.toCharArray()) {
+                if (Character.isLowerCase(ch)) {
+                    result.append(Character.toUpperCase(ch));
+                } else if (Character.isUpperCase(ch)) {
+                    result.append(Character.toLowerCase(ch));
                 } else {
-                    result.append(origin.charAt(icounter));
+                    result.append(ch);
                 }
             }
             return result.toString();
@@ -713,7 +710,7 @@ public class FTPTaskMirrorImpl implements FTPTaskMirror {
             public AntFTPFile(AntFTPFile parent, String path) {
                 this.parent = parent;
                 this.client = parent.client;
-                Vector pathElements = SelectorUtils.tokenizePath(path);
+                Vector<String> pathElements = SelectorUtils.tokenizePath(path);
                 try {
                     boolean result = this.client.changeWorkingDirectory(parent.getAbsolutePath());
                     //this should not happen, except if parent has been deleted by another process
@@ -722,18 +719,15 @@ public class FTPTaskMirrorImpl implements FTPTaskMirror {
                     }
                     this.curpwd = parent.getAbsolutePath();
                 } catch (IOException ioe) {
-                    throw new BuildException("could not change working dir to "
-                                             + parent.curpwd);
+                    throw new BuildException("could not change working dir to " + parent.curpwd);
                 }
-                final int size = pathElements.size();
-                for (int fcount = 0; fcount < size - 1; fcount++) {
-                    String currentPathElement = (String) pathElements.elementAt(fcount);
+                for (String currentPathElement : pathElements) {
                     try {
                         boolean result = this.client.changeWorkingDirectory(currentPathElement);
                         if (!result && !isCaseSensitive()
                             && (remoteSystemCaseSensitive || !remoteSensitivityChecked)) {
                             currentPathElement = findPathElementCaseUnsensitive(this.curpwd,
-                                                                                currentPathElement);
+                                    currentPathElement);
                             if (currentPathElement == null) {
                                 return;
                             }
@@ -744,17 +738,15 @@ public class FTPTaskMirrorImpl implements FTPTaskMirror {
                             + currentPathElement;
                     } catch (IOException ioe) {
                         throw new BuildException("could not change working dir to "
-                                                 + (String) pathElements.elementAt(fcount)
-                                                 + " from " + this.curpwd);
+                                + currentPathElement + " from " + this.curpwd);
                     }
 
                 }
-                String lastpathelement = (String) pathElements.elementAt(size - 1);
-                FTPFile [] theFiles = listFiles(this.curpwd);
-                this.ftpFile = getFile(theFiles, lastpathelement);
+                String lastpathelement = pathElements.get(pathElements.size() - 1);
+                this.ftpFile = getFile(listFiles(this.curpwd), lastpathelement);
             }
             /**
-             * find a file in a directory in case unsensitive way
+             * find a file in a directory in case insensitive way
              * @param parentPath        where we are
              * @param soughtPathElement what is being sought
              * @return                  the first file found or null if not found
@@ -763,14 +755,13 @@ public class FTPTaskMirrorImpl implements FTPTaskMirror {
                                                           String soughtPathElement) {
                 // we are already in the right path, so the second parameter
                 // is false
-                FTPFile[] theFiles = listFiles(parentPath, false);
-                if (theFiles == null) {
+                FTPFile[] files = listFiles(parentPath, false);
+                if (files == null) {
                     return null;
                 }
-                for (int icounter = 0; icounter < theFiles.length; icounter++) {
-                    if (theFiles[icounter] != null
-                        && theFiles[icounter].getName().equalsIgnoreCase(soughtPathElement)) {
-                        return theFiles[icounter].getName();
+                for (FTPFile file : files) {
+                    if (file != null && file.getName().equalsIgnoreCase(soughtPathElement)) {
+                        return file.getName();
                     }
                 }
                 return null;
@@ -1061,7 +1052,7 @@ public class FTPTaskMirrorImpl implements FTPTaskMirror {
                                           Project.MSG_ERR);
                 } finally {
                     if (!comeback) {
-                        throw new BuildException("could not cd back to " + dir
+                        throw new BuildException("could not cd back to " + dir //NOSONAR
                                                  + " while checking a symlink");
                     }
                 }
@@ -1091,7 +1082,7 @@ public class FTPTaskMirrorImpl implements FTPTaskMirror {
      * Executable a retryable object.
      * @param h the retry handler.
      * @param r the object that should be retried until it succeeds
-     *          or the number of retrys is reached.
+     *          or the number of retries is reached.
      * @param descr a description of the command that is being run.
      * @throws IOException if there is a problem.
      */
@@ -1174,11 +1165,10 @@ public class FTPTaskMirrorImpl implements FTPTaskMirror {
                     task.setGranularityMillis(task.getTimestampGranularity()
                                               .getMilliseconds(task.getAction()));
                 }
-                for (int i = 0; i < dsfiles.length; i++) {
-                    final String dsfile = dsfiles[i];
+                for (final String dsfile : dsfiles) {
                     executeRetryable(h, new Retryable() {
-                            public void execute() throws IOException {
-                                switch (task.getAction()) {
+                        public void execute() throws IOException {
+                            switch (task.getAction()) {
                                 case FTPTask.SEND_FILES:
                                     sendFile(ftp, fdir, dsfile);
                                     break;
@@ -1199,9 +1189,9 @@ public class FTPTaskMirrorImpl implements FTPTaskMirror {
                                 default:
                                     throw new BuildException("unknown ftp action "
                                                              + task.getAction());
-                                }
                             }
-                        }, dsfile);
+                        }
+                    }, dsfile);
                 }
             }
         } finally {
@@ -1373,7 +1363,7 @@ public class FTPTaskMirrorImpl implements FTPTaskMirror {
      *  find a suitable name for local and remote temporary file
      */
     private File findFileName(FTPClient ftp) {
-        FTPFile [] theFiles = null;
+        FTPFile[] files = null;
         final int maxIterations = 1000;
         for (int counter = 1; counter < maxIterations; counter++) {
             File localFile = FILE_UTILS.createTempFile(
@@ -1382,12 +1372,11 @@ public class FTPTaskMirrorImpl implements FTPTaskMirror {
             String fileName = localFile.getName();
             boolean found = false;
             try {
-                if (theFiles == null) {
-                    theFiles = ftp.listFiles();
+                if (files == null) {
+                    files = ftp.listFiles();
                 }
-                for (int counter2 = 0; counter2 < theFiles.length; counter2++) {
-                    if (theFiles[counter2] != null
-                        && theFiles[counter2].getName().equals(fileName)) {
+                for (FTPFile file : files) {
+                    if (file != null && file.getName().equals(fileName)) {
                         found = true;
                         break;
                     }
@@ -1443,20 +1432,20 @@ public class FTPTaskMirrorImpl implements FTPTaskMirror {
             + task.getGranularityMillis();
 
         StringBuffer msg;
-        synchronized(TIMESTAMP_LOGGING_SDF) {
+        synchronized (TIMESTAMP_LOGGING_SDF) {
             msg = new StringBuffer("   [")
                 .append(TIMESTAMP_LOGGING_SDF.format(new Date(localTimestamp)))
                 .append("] local");
         }
         task.log(msg.toString(), Project.MSG_VERBOSE);
 
-        synchronized(TIMESTAMP_LOGGING_SDF) {
+        synchronized (TIMESTAMP_LOGGING_SDF) {
             msg = new StringBuffer("   [")
                 .append(TIMESTAMP_LOGGING_SDF.format(new Date(adjustedRemoteTimestamp)))
                 .append("] remote");
         }
         if (remoteTimestamp != adjustedRemoteTimestamp) {
-            synchronized(TIMESTAMP_LOGGING_SDF) {
+            synchronized (TIMESTAMP_LOGGING_SDF) {
                 msg.append(" - (raw: ")
                     .append(TIMESTAMP_LOGGING_SDF.format(new Date(remoteTimestamp)))
                     .append(")");
@@ -1491,12 +1480,9 @@ public class FTPTaskMirrorImpl implements FTPTaskMirror {
         if (!rc) {
             task.log("Failed to issue Site Command: " + theCMD, Project.MSG_WARN);
         } else {
-
-            myReply = ftp.getReplyStrings();
-
-            for (int x = 0; x < myReply.length; x++) {
-                if (myReply[x].indexOf("200") == -1) {
-                    task.log(myReply[x], Project.MSG_WARN);
+            for (String reply : ftp.getReplyStrings()) {
+                if (!reply.contains("200")) {
+                    task.log(reply, Project.MSG_WARN);
                 }
             }
         }
@@ -1634,7 +1620,7 @@ public class FTPTaskMirrorImpl implements FTPTaskMirror {
      * Retrieve a single file from the remote host. <code>filename</code> may
      * contain a relative path specification. <p>
      *
-     * The file will then be retreived using the entire relative path spec -
+     * The file will then be retrieved using the entire relative path spec -
      * no attempt is made to change directories. It is anticipated that this
      * may eventually cause problems with some FTP servers, but it simplifies
      * the coding.</p>
@@ -1936,4 +1922,3 @@ public class FTPTaskMirrorImpl implements FTPTaskMirror {
         }
     }
 }
-
