@@ -26,6 +26,7 @@ package org.apache.tools.tar;
 import java.io.IOException;
 import java.math.BigInteger;
 import java.nio.ByteBuffer;
+
 import org.apache.tools.zip.ZipEncoding;
 import org.apache.tools.zip.ZipEncodingHelper;
 
@@ -45,11 +46,13 @@ public class TarUtils {
      * Encapsulates the algorithms used up to Ant 1.8 as ZipEncoding.
      */
     static final ZipEncoding FALLBACK_ENCODING = new ZipEncoding() {
-            public boolean canEncode(String name) { return true; }
+            public boolean canEncode(final String name) {
+                return true;
+            }
 
-            public ByteBuffer encode(String name) {
+            public ByteBuffer encode(final String name) {
                 final int length = name.length();
-                byte[] buf = new byte[length];
+                final byte[] buf = new byte[length];
 
                 // copy until end of input or output is reached.
                 for (int i = 0; i < length; ++i) {
@@ -58,12 +61,11 @@ public class TarUtils {
                 return ByteBuffer.wrap(buf);
             }
 
-            public String decode(byte[] buffer) {
+            public String decode(final byte[] buffer) {
                 final int length = buffer.length;
-                StringBuffer result = new StringBuffer(length);
+                final StringBuilder result = new StringBuilder(length);
 
-                for (int i = 0; i < length; ++i) {
-                    byte b = buffer[i];
+                for (final byte b : buffer) {
                     if (b == 0) { // Trailing null
                         break;
                     }
@@ -75,7 +77,7 @@ public class TarUtils {
         };
 
     /** Private constructor to prevent instantiation of this utility class. */
-    private TarUtils(){
+    private TarUtils() {
     }
 
     /**
@@ -104,8 +106,8 @@ public class TarUtils {
         int     end = offset + length;
         int     start = offset;
 
-        if (length < 2){
-            throw new IllegalArgumentException("Length "+length+" must be at least 2");
+        if (length < 2) {
+            throw new IllegalArgumentException("Length " + length + " must be at least 2");
         }
 
         if (buffer[start] == 0) {
@@ -113,8 +115,8 @@ public class TarUtils {
         }
 
         // Skip leading spaces
-        while (start < end){
-            if (buffer[start] == ' '){
+        while (start < end) {
+            if (buffer[start] == ' ') {
                 start++;
             } else {
                 break;
@@ -130,26 +132,23 @@ public class TarUtils {
             end--;
             trailer = buffer[end - 1];
         }
-        if (start == end) {
-            throw new IllegalArgumentException(
-                    exceptionMessage(buffer, offset, length, start, trailer));
-        }
 
-        for ( ;start < end; start++) {
+        while (start < end) {
             final byte currentByte = buffer[start];
             // CheckStyle:MagicNumber OFF
-            if (currentByte < '0' || currentByte > '7'){
+            if (currentByte < '0' || currentByte > '7') {
                 throw new IllegalArgumentException(
                         exceptionMessage(buffer, offset, length, start, currentByte));
             }
             result = (result << 3) + (currentByte - '0'); // convert from ASCII
             // CheckStyle:MagicNumber ON
+            start++;
         }
 
         return result;
     }
 
-    /** 
+    /**
      * Compute the value contained in a byte buffer.  If the most
      * significant bit of the first byte in the buffer is set, this
      * bit is ignored and the rest of the buffer is interpreted as a
@@ -182,10 +181,9 @@ public class TarUtils {
                                         final int length,
                                         final boolean negative) {
         if (length >= 9) {
-            throw new IllegalArgumentException("At offset " + offset + ", "
-                                               + length + " byte binary number"
-                                               + " exceeds maximum signed long"
-                                               + " value");
+            throw new IllegalArgumentException(String.format(
+                    "At offset %d, %d byte binary number exceeds maximum signed long value",
+                    offset, length));
         }
         long val = 0;
         for (int i = 1; i < length; i++) {
@@ -194,7 +192,7 @@ public class TarUtils {
         if (negative) {
             // 2's complement
             val--;
-            val ^= ((long) Math.pow(2, (length - 1) * 8) - 1);
+            val ^= (long) Math.pow(2, (length - 1) * 8.0) - 1;
         }
         return negative ? -val : val;
     }
@@ -203,7 +201,7 @@ public class TarUtils {
                                               final int offset,
                                               final int length,
                                               final boolean negative) {
-        byte[] remainder = new byte[length - 1];
+        final byte[] remainder = new byte[length - 1];
         System.arraycopy(buffer, offset + 1, remainder, 0, length - 1);
         BigInteger val = new BigInteger(remainder);
         if (negative) {
@@ -211,10 +209,9 @@ public class TarUtils {
             val = val.add(BigInteger.valueOf(-1)).not();
         }
         if (val.bitLength() > 63) {
-            throw new IllegalArgumentException("At offset " + offset + ", "
-                                               + length + " byte binary number"
-                                               + " exceeds maximum signed long"
-                                               + " value");
+            throw new IllegalArgumentException(String.format(
+                    "At offset %d, %d byte binary number exceeds maximum signed long value",
+                    offset, length));
         }
         return negative ? -val.longValue() : val.longValue();
     }
@@ -234,12 +231,20 @@ public class TarUtils {
     }
 
     // Helper method to generate the exception message
-    private static String exceptionMessage(byte[] buffer, final int offset,
-            final int length, int current, final byte currentByte) {
-        String string = new String(buffer, offset, length); // TODO default charset?
-        string=string.replaceAll("\0", "{NUL}"); // Replace NULs to allow string to be printed
-        final String s = "Invalid byte "+currentByte+" at offset "+(current-offset)+" in '"+string+"' len="+length;
-        return s;
+    private static String exceptionMessage(final byte[] buffer, final int offset,
+            final int length, final int current, final byte currentByte) {
+        // default charset is good enough for an exception message,
+        //
+        // the alternative was to modify parseOctal and
+        // parseOctalOrBinary to receive the ZipEncoding of the
+        // archive (deprecating the existing public methods, of
+        // course) and dealing with the fact that ZipEncoding#decode
+        // can throw an IOException which parseOctal* doesn't declare
+        String string = new String(buffer, offset, length);
+
+        string = string.replaceAll("\0", "{NUL}"); // Replace NULs to allow string to be printed
+        return String.format("Invalid byte %s at offset %d in '%s' len=%d",
+                currentByte, current - offset, string, length);
     }
 
     /**
@@ -252,15 +257,15 @@ public class TarUtils {
      * @param length The maximum number of bytes to parse.
      * @return The entry name.
      */
-    public static String parseName(byte[] buffer, final int offset, final int length) {
+    public static String parseName(final byte[] buffer, final int offset, final int length) {
         try {
             return parseName(buffer, offset, length, DEFAULT_ENCODING);
-        } catch (IOException ex) {
+        } catch (final IOException ex) {
             try {
                 return parseName(buffer, offset, length, FALLBACK_ENCODING);
-            } catch (IOException ex2) {
+            } catch (final IOException ex2) {
                 // impossible
-                throw new RuntimeException(ex2);
+                throw new RuntimeException(ex2); //NOSONAR
             }
         }
     }
@@ -275,8 +280,9 @@ public class TarUtils {
      * @param length The maximum number of bytes to parse.
      * @param encoding name of the encoding to use for file names
      * @return The entry name.
+     * @throws IOException if decode fails
      */
-    public static String parseName(byte[] buffer, final int offset,
+    public static String parseName(final byte[] buffer, final int offset,
                                    final int length,
                                    final ZipEncoding encoding)
         throws IOException {
@@ -288,7 +294,7 @@ public class TarUtils {
             }
         }
         if (len > 0) {
-            byte[] b = new byte[len];
+            final byte[] b = new byte[len];
             System.arraycopy(buffer, offset, b, 0, len);
             return encoding.decode(b);
         }
@@ -298,7 +304,7 @@ public class TarUtils {
     /**
      * Copy a name into a buffer.
      * Copies characters from the name into the buffer
-     * starting at the specified offset. 
+     * starting at the specified offset.
      * If the buffer is longer than the name, the buffer
      * is filled with trailing NULs.
      * If the name is longer than the buffer,
@@ -310,16 +316,16 @@ public class TarUtils {
      * @param length The maximum number of header bytes to copy.
      * @return The updated offset, i.e. offset + length
      */
-    public static int formatNameBytes(String name, byte[] buf, final int offset, final int length) {
+    public static int formatNameBytes(final String name, final byte[] buf, final int offset, final int length) {
         try {
             return formatNameBytes(name, buf, offset, length, DEFAULT_ENCODING);
-        } catch (IOException ex) {
+        } catch (final IOException ex) {
             try {
                 return formatNameBytes(name, buf, offset, length,
                                        FALLBACK_ENCODING);
-            } catch (IOException ex2) {
+            } catch (final IOException ex2) {
                 // impossible
-                throw new RuntimeException(ex2);
+                throw new RuntimeException(ex2); //NOSONAR
             }
         }
     }
@@ -327,7 +333,7 @@ public class TarUtils {
     /**
      * Copy a name into a buffer.
      * Copies characters from the name into the buffer
-     * starting at the specified offset. 
+     * starting at the specified offset.
      * If the buffer is longer than the name, the buffer
      * is filled with trailing NULs.
      * If the name is longer than the buffer,
@@ -339,8 +345,9 @@ public class TarUtils {
      * @param length The maximum number of header bytes to copy.
      * @param encoding name of the encoding to use for file names
      * @return The updated offset, i.e. offset + length
+     * @throws IOException if encode fails
      */
-    public static int formatNameBytes(String name, byte[] buf, final int offset,
+    public static int formatNameBytes(final String name, final byte[] buf, final int offset,
                                       final int length,
                                       final ZipEncoding encoding)
         throws IOException {
@@ -362,14 +369,14 @@ public class TarUtils {
 
     /**
      * Fill buffer with unsigned octal number, padded with leading zeroes.
-     * 
+     *
      * @param value number to convert to octal - treated as unsigned
      * @param buffer destination buffer
      * @param offset starting offset in buffer
      * @param length length of buffer to fill
      * @throws IllegalArgumentException if the value will not fit in the buffer
      */
-    public static void formatUnsignedOctalString(final long value, byte[] buffer,
+    public static void formatUnsignedOctalString(final long value, final byte[] buffer,
             final int offset, final int length) {
         int remaining = length;
         remaining--;
@@ -383,9 +390,10 @@ public class TarUtils {
                 val = val >>> 3;
                 // CheckStyle:MagicNumber ON
             }
-            if (val != 0){
-                throw new IllegalArgumentException
-                (value+"="+Long.toOctalString(value)+ " will not fit in octal number buffer of length "+length);
+            if (val != 0) {
+                throw new IllegalArgumentException(String.format(
+                        "%d=%s will not fit in octal number buffer of length %d",
+                        value, Long.toOctalString(value), length));
             }
         }
 
@@ -400,7 +408,7 @@ public class TarUtils {
      * Uses {@link #formatUnsignedOctalString} to format
      * the value as an octal string with leading zeros.
      * The converted number is followed by space and NUL
-     * 
+     *
      * @param value The value to write
      * @param buf The buffer to receive the output
      * @param offset The starting offset into the buffer
@@ -408,9 +416,9 @@ public class TarUtils {
      * @return The updated offset, i.e offset+length
      * @throws IllegalArgumentException if the value (and trailer) will not fit in the buffer
      */
-    public static int formatOctalBytes(final long value, byte[] buf, final int offset, final int length) {
+    public static int formatOctalBytes(final long value, final byte[] buf, final int offset, final int length) {
 
-        int idx=length-2; // For space and trailing null
+        int idx = length - 2; // For space and trailing null
         formatUnsignedOctalString(value, buf, offset, idx);
 
         buf[offset + idx++] = (byte) ' '; // Trailing space
@@ -421,11 +429,11 @@ public class TarUtils {
 
     /**
      * Write an octal long integer into a buffer.
-     * 
+     *
      * Uses {@link #formatUnsignedOctalString} to format
      * the value as an octal string with leading zeros.
      * The converted number is followed by a space.
-     * 
+     *
      * @param value The value to write as octal
      * @param buf The destinationbuffer.
      * @param offset The starting offset into the buffer.
@@ -433,9 +441,9 @@ public class TarUtils {
      * @return The updated offset
      * @throws IllegalArgumentException if the value (and trailer) will not fit in the buffer
      */
-    public static int formatLongOctalBytes(final long value, byte[] buf, final int offset, final int length) {
+    public static int formatLongOctalBytes(final long value, final byte[] buf, final int offset, final int length) {
 
-        int idx=length-1; // For space
+        final int idx = length - 1; // For space
 
         formatUnsignedOctalString(value, buf, offset, idx);
         buf[offset + idx] = (byte) ' '; // Trailing space
@@ -446,11 +454,11 @@ public class TarUtils {
     /**
      * Write an long integer into a buffer as an octal string if this
      * will fit, or as a binary number otherwise.
-     * 
+     *
      * Uses {@link #formatUnsignedOctalString} to format
      * the value as an octal string with leading zeros.
      * The converted number is followed by a space.
-     * 
+     *
      * @param value The value to write into the buffer.
      * @param buf The destination buffer.
      * @param offset The starting offset into the buffer.
@@ -460,7 +468,7 @@ public class TarUtils {
      * will not fit in the buffer.
      */
     public static int formatLongOctalOrBinaryBytes(
-        final long value, byte[] buf, final int offset, final int length) {
+        final long value, final byte[] buf, final int offset, final int length) {
 
         // Check whether we are dealing with UID/GID or SIZE field
         final long maxAsOctalChar = length == TarConstants.UIDLEN ? TarConstants.MAXID : TarConstants.MAXSIZE;
@@ -479,11 +487,11 @@ public class TarUtils {
         return offset + length;
     }
 
-    private static void formatLongBinary(final long value, byte[] buf,
+    private static void formatLongBinary(final long value, final byte[] buf,
                                          final int offset, final int length,
                                          final boolean negative) {
         final int bits = (length - 1) * 8;
-        final long max = 1l << bits;
+        final long max = 1L << bits;
         long val = Math.abs(value);
         if (val >= max) {
             throw new IllegalArgumentException("Value " + value +
@@ -500,11 +508,11 @@ public class TarUtils {
         }
     }
 
-    private static void formatBigIntegerBinary(final long value, byte[] buf,
+    private static void formatBigIntegerBinary(final long value, final byte[] buf,
                                                final int offset,
                                                final int length,
                                                final boolean negative) {
-        BigInteger val = BigInteger.valueOf(value);
+        final BigInteger val = BigInteger.valueOf(value);
         final byte[] b = val.toByteArray();
         final int len = b.length;
         final int off = offset + length - len;
@@ -517,7 +525,7 @@ public class TarUtils {
 
     /**
      * Writes an octal value into a buffer.
-     * 
+     *
      * Uses {@link #formatUnsignedOctalString} to format
      * the value as an octal string with leading zeros.
      * The converted number is followed by NUL and then space.
@@ -529,13 +537,13 @@ public class TarUtils {
      * @return The updated value of offset, i.e. offset+length
      * @throws IllegalArgumentException if the value (and trailer) will not fit in the buffer
      */
-    public static int formatCheckSumOctalBytes(final long value, byte[] buf, final int offset, final int length) {
+    public static int formatCheckSumOctalBytes(final long value, final byte[] buf, final int offset, final int length) {
 
-        int idx=length-2; // for NUL and space
+        int idx = length - 2; // for NUL and space
         formatUnsignedOctalString(value, buf, offset, idx);
 
-        buf[offset + idx++]   = 0; // Trailing null
-        buf[offset + idx]     = (byte) ' '; // Trailing space
+        buf[offset + idx++] = 0; // Trailing null
+        buf[offset + idx]   = (byte) ' '; // Trailing space
 
         return offset + length;
     }
@@ -549,8 +557,8 @@ public class TarUtils {
     public static long computeCheckSum(final byte[] buf) {
         long sum = 0;
 
-        for (int i = 0; i < buf.length; ++i) {
-            sum += BYTE_MASK & buf[i];
+        for (final byte element : buf) {
+            sum += BYTE_MASK & element;
         }
 
         return sum;
