@@ -24,7 +24,6 @@ import org.junit.Rule;
 import org.junit.Test;
 
 import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.List;
 
 import static org.junit.Assert.assertEquals;
@@ -57,17 +56,22 @@ public class UnknownElementTest {
     @Ignore("Previously disabled through naming convention")
     public void XtestTaskFinishedEvent() {
         buildRule.getProject().addBuildListener(new BuildListener() {
-                public void buildStarted(BuildEvent event) {}
-                public void buildFinished(BuildEvent event) {}
-                public void targetStarted(BuildEvent event) {}
-                public void targetFinished(BuildEvent event) {}
+                public void buildStarted(BuildEvent event) {
+                }
+                public void buildFinished(BuildEvent event) {
+                }
+                public void targetStarted(BuildEvent event) {
+                }
+                public void targetFinished(BuildEvent event) {
+                }
                 public void taskStarted(BuildEvent event) {
                     assertTaskProperties(event.getTask());
                 }
                 public void taskFinished(BuildEvent event) {
                     assertTaskProperties(event.getTask());
                 }
-                public void messageLogged(BuildEvent event) {}
+                public void messageLogged(BuildEvent event) {
+                }
                 private void assertTaskProperties(Task ue) {
                     assertNotNull(ue);
                     assertTrue(ue instanceof UnknownElement);
@@ -91,7 +95,7 @@ public class UnknownElementTest {
     }
 
     public static class Parent extends Task implements TaskContainer {
-        List children = new ArrayList();
+        List<Task> children = new ArrayList<Task>();
         public void addTask(Task t) {
             children.add(t);
         }
@@ -101,8 +105,8 @@ public class UnknownElementTest {
         }
 
         public void execute() {
-            for (Iterator i = children.iterator(); i.hasNext();) {
-                UnknownElement el = (UnknownElement) i.next();
+            for (Task task : children) {
+                UnknownElement el = (UnknownElement) task;
                 el.maybeConfigure();
                 Child child = (Child) el.getRealThing();
                 child.injectParent(this);
@@ -111,5 +115,3 @@ public class UnknownElementTest {
         }
     }
 }
-
-
