@@ -40,7 +40,7 @@ import static org.junit.Assert.assertEquals;
 public class DefaultCompilerAdapterTest {
 
     private static class LogCapturingJavac extends Javac {
-        private StringBuffer sb = new StringBuffer();
+        private StringBuilder sb = new StringBuilder();
         public void log(String msg, int msgLevel) {
             sb.append(msg);
         }
@@ -58,7 +58,23 @@ public class DefaultCompilerAdapterTest {
             return cmd;
         }
 
-        public boolean execute() { return false; }
+        public boolean execute() {
+            return false;
+        }
+
+        /**
+         * public to avoid classloader issues.
+         */
+        public Commandline setupModernJavacCommandlineSwitches(Commandline cmd) {
+            return super.setupModernJavacCommandlineSwitches(cmd);
+        }
+    }
+
+    private static class SourceTargetHelperNoOverride extends DefaultCompilerAdapter {
+
+        public boolean execute() {
+            return false;
+        }
 
         /**
          * public to avoid classloader issues.
@@ -185,14 +201,45 @@ public class DefaultCompilerAdapterTest {
         testSource(null, "javac1.9", "", "9");
     }
 
+    @Test
+    public void testImplicitSourceForJava9() {
+        commonSourceDowngrades("javac9");
+        testSource("1.5", "javac9",
+                   "If you specify -target 1.5 you now must also specify"
+                   + " -source 1.5", "1.5");
+        testSource("1.6", "javac1.9",
+                   "If you specify -target 1.6 you now must also specify"
+                   + " -source 1.6", "1.6");
+        testSource("1.7", "javac9",
+                   "If you specify -target 1.7 you now must also specify"
+                   + " -source 1.7", "1.7");
+        testSource("1.8", "javac9",
+                   "If you specify -target 1.8 you now must also specify"
+                   + " -source 1.8", "1.8");
+        testSource("5", "javac9",
+                   "If you specify -target 5 you now must also specify"
+                   + " -source 5", "5");
+        testSource("6", "javac9",
+                   "If you specify -target 6 you now must also specify"
+                   + " -source 6", "6");
+        testSource("7", "javac9",
+                   "If you specify -target 7 you now must also specify"
+                   + " -source 7", "7");
+        testSource("8", "javac9",
+                   "If you specify -target 8 you now must also specify"
+                   + " -source 8", "8");
+        testSource(null, "javac9", "", "1.9");
+        testSource(null, "javac9", "", "9");
+    }
+
     @Test
     public void testSingleModuleCompilation() throws IOException {
         final File workDir = createWorkDir("testSMC");
         try {
             final File src = new File(workDir, "src");
             src.mkdir();
-            final File java1 = createFile(src,"org/apache/ant/tests/J1.java");
-            final File java2 = createFile(src,"org/apache/ant/tests/J2.java");
+            final File java1 = createFile(src, "org/apache/ant/tests/J1.java");
+            final File java2 = createFile(src, "org/apache/ant/tests/J2.java");
             final File modules = new File(workDir, "modules");
             modules.mkdir();
             final Project prj = new Project();
@@ -218,20 +265,19 @@ public class DefaultCompilerAdapterTest {
             Assert.assertNotNull(cmd[0]);
             final List<String> cmdLine = Arrays.asList(cmd[0].getCommandline());
             //No modulesourcepath
-            assertEquals(-1, cmdLine.indexOf("-modulesourcepath"));
+            assertEquals(-1, cmdLine.indexOf("--module-source-path"));
             //The -sourcepath has to be followed by src
             int index = cmdLine.indexOf("-sourcepath");
             Assert.assertTrue(index != -1 && index < cmdLine.size() - 1);
             assertEquals(src.getAbsolutePath(), cmdLine.get(index + 1));
-            //The -modulepath has to be followed by modules
-            index = cmdLine.indexOf("-modulepath");
+            //The --module-path has to be followed by modules
+            index = cmdLine.indexOf("--module-path");
             Assert.assertTrue(index != -1 && index < cmdLine.size() - 1);
             assertEquals(modules.getAbsolutePath(), cmdLine.get(index + 1));
             //J1.java & J2.java has to be in files list
             final Set<String> expected = new TreeSet<String>();
             Collections.addAll(expected, java1.getAbsolutePath(), java2.getAbsolutePath());
-            final Set<String> actual = new TreeSet<String>();
-            actual.addAll(cmdLine.subList(cmdLine.size() - 2, cmdLine.size()));
+            final Set<String> actual = new TreeSet<String>(cmdLine.subList(cmdLine.size() - 2, cmdLine.size()));
             assertEquals(expected, actual);
         } finally {
             delete(workDir);
@@ -244,9 +290,9 @@ public class DefaultCompilerAdapterTest {
         try {
             final File src = new File(workDir, "src");
             src.mkdir();
-            final File java1 = createFile(src,"main/m1/lin64/classes/org/apache/ant/tests/J1.java");
-            final File java2 = createFile(src,"main/m2/lin32/classes/org/apache/ant/tests/J2.java");
-            final File java3 = createFile(src,"main/m3/sol/classes/org/apache/ant/tests/J3.java");
+            final File java1 = createFile(src, "main/m1/lin64/classes/org/apache/ant/tests/J1.java");
+            final File java2 = createFile(src, "main/m2/lin32/classes/org/apache/ant/tests/J2.java");
+            final File java3 = createFile(src, "main/m3/sol/classes/org/apache/ant/tests/J3.java");
             final File modules = new File(workDir, "modules");
             modules.mkdir();
             final File build = new File(workDir, "build");
@@ -277,8 +323,8 @@ public class DefaultCompilerAdapterTest {
             final List<String> cmdLine = Arrays.asList(cmd[0].getCommandline());
             //No sourcepath
             assertEquals(-1, cmdLine.indexOf("-sourcepath"));
-            //The -modulesourcepath has to be followed by the pattern
-            int index = cmdLine.indexOf("-modulesourcepath");
+            //The --module-source-path has to be followed by the pattern
+            int index = cmdLine.indexOf("--module-source-path");
             Assert.assertTrue(index != -1 && index < cmdLine.size() - 1);
             String expectedModSrcPath = String.format("%s/%s",
                     workDir.getAbsolutePath(),
@@ -286,8 +332,8 @@ public class DefaultCompilerAdapterTest {
                     .replace('/', File.separatorChar)
                     .replace('\\', File.separatorChar);
             assertEquals(expectedModSrcPath, cmdLine.get(index + 1));
-            //The -modulepath has to be followed by modules
-            index = cmdLine.indexOf("-modulepath");
+            //The --module-path has to be followed by modules
+            index = cmdLine.indexOf("--module-path");
             Assert.assertTrue(index != -1 && index < cmdLine.size() - 1);
             assertEquals(modules.getAbsolutePath(), cmdLine.get(index + 1));
             //J1.java, J2.java & J3.java has to be in files list
@@ -296,8 +342,7 @@ public class DefaultCompilerAdapterTest {
                     java1.getAbsolutePath(),
                     java2.getAbsolutePath(),
                     java3.getAbsolutePath());
-            final Set<String> actualFiles = new TreeSet<String>();
-            actualFiles.addAll(cmdLine.subList(cmdLine.size() - 3, cmdLine.size()));
+            final Set<String> actualFiles = new TreeSet<String>(cmdLine.subList(cmdLine.size() - 3, cmdLine.size()));
             assertEquals(expectedFiles, actualFiles);
         } finally {
             delete(workDir);
@@ -310,9 +355,10 @@ public class DefaultCompilerAdapterTest {
         try {
             final File src = new File(workDir, "src");
             src.mkdir();
-            final File java1 = createFile(src,"main/m1/lin/classes/org/apache/ant/tests/J1.java");
-            final File java2 = createFile(src,"main/m3/sol/classes/org/apache/ant/tests/J2.java");
-            final File java3 = createFile(src,"main/m3/sol/classes/org/apache/ant/invisible/J3.java");
+            final File java1 = createFile(src, "main/m1/lin/classes/org/apache/ant/tests/J1.java");
+            final File java2 = createFile(src, "main/m3/sol/classes/org/apache/ant/tests/J2.java");
+            @SuppressWarnings("unused")
+            final File java3 = createFile(src, "main/m3/sol/classes/org/apache/ant/invisible/J3.java");
             final File build = new File(workDir, "build");
             build.mkdirs();
             final Project prj = new Project();
@@ -353,6 +399,56 @@ public class DefaultCompilerAdapterTest {
         }
     }
 
+    @Test
+    public void releaseIsIgnoredForJava8() {
+        LogCapturingJavac javac = new LogCapturingJavac();
+        Project p = new Project();
+        javac.setProject(p);
+        javac.setCompiler("javac8");
+        javac.setSource("6");
+        javac.setTarget("6");
+        javac.setRelease("6");
+        javac.setSourcepath(new Path(p));
+        SourceTargetHelperNoOverride sth = new SourceTargetHelperNoOverride();
+        sth.setJavac(javac);
+        Commandline cmd = new Commandline();
+        sth.setupModernJavacCommandlineSwitches(cmd);
+        assertContains("Support for javac --release has been added in "
+                       + "Java9 ignoring it", javac.getLog());
+        String[] args = cmd.getCommandline();
+        assertEquals(7, args.length);
+        assertEquals("-classpath", args[0]);
+        assertEquals("-target", args[2]);
+        assertEquals("6", args[3]);
+        assertEquals("-g:none", args[4]);
+        assertEquals("-source", args[5]);
+        assertEquals("6", args[6]);
+    }
+
+    @Test
+    public void releaseIsUsedForJava9() {
+        LogCapturingJavac javac = new LogCapturingJavac();
+        Project p = new Project();
+        javac.setProject(p);
+        javac.setCompiler("javac9");
+        javac.setSource("6");
+        javac.setTarget("6");
+        javac.setRelease("6");
+        javac.setSourcepath(new Path(p));
+        SourceTargetHelperNoOverride sth = new SourceTargetHelperNoOverride();
+        sth.setJavac(javac);
+        Commandline cmd = new Commandline();
+        sth.setupModernJavacCommandlineSwitches(cmd);
+        assertContains("Ignoring source, target and bootclasspath as "
+                       + "release has been set", javac.getLog());
+        String[] args = cmd.getCommandline();
+        assertEquals(5, args.length);
+        assertEquals("-classpath", args[0]);
+        assertEquals("-g:none", args[2]);
+        assertEquals("--release", args[3]);
+        assertEquals("6", args[4]);
+    }
+
     private void commonSourceDowngrades(String javaVersion) {
         testSource("1.3", javaVersion,
                    "If you specify -target 1.1 you now must also specify"
@@ -405,7 +501,7 @@ public class DefaultCompilerAdapterTest {
         final File destDir = new File(tmp, String.format("%s%s%d",
                 getClass().getName(),
                 testName,
-                System.currentTimeMillis()/1000));
+                System.currentTimeMillis() / 1000));
         destDir.mkdirs();
         return destDir;
     }
