@@ -23,7 +23,6 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.NoSuchElementException;
 
-
 import org.apache.tools.ant.types.Resource;
 import org.apache.tools.ant.types.ResourceCollection;
 import org.junit.Test;
@@ -82,8 +81,7 @@ public class LazyResourceCollectionTest {
 
         Iterator<Resource> it = lazyCollection.iterator();
         assertOneCreatedIterator(collectionTest);
-        StringResourceIterator stringResourceIterator = (StringResourceIterator) collectionTest.createdIterators
-                .get(0);
+        StringResourceIterator stringResourceIterator = (StringResourceIterator) collectionTest.createdIterators.get(0);
         assertEquals("A resource was loaded without iterating", 1,
                 stringResourceIterator.cursor);
 
@@ -131,8 +129,7 @@ public class LazyResourceCollectionTest {
         Iterator<Resource> it2 = lazyCollection.iterator();
         assertOneCreatedIterator(collectionTest);
 
-        StringResourceIterator stringResourceIterator = (StringResourceIterator) collectionTest.createdIterators
-                .get(0);
+        StringResourceIterator stringResourceIterator = (StringResourceIterator) collectionTest.createdIterators.get(0);
         assertEquals("A resource was loaded without iterating", 1,
                 stringResourceIterator.cursor);
 
@@ -143,8 +140,7 @@ public class LazyResourceCollectionTest {
 
         r = (StringResource) it2.next();
         assertEquals("r1", r.getValue());
-        assertEquals(
-                "The second iterator did not lookup in the cache for a resource",
+        assertEquals("The second iterator did not lookup in the cache for a resource",
                 2, stringResourceIterator.cursor);
 
         r = (StringResource) it2.next();
@@ -154,8 +150,7 @@ public class LazyResourceCollectionTest {
 
         r = (StringResource) it1.next();
         assertEquals("r2", r.getValue());
-        assertEquals(
-                "The first iterator did not lookup in the cache for a resource",
+        assertEquals("The first iterator did not lookup in the cache for a resource",
                 3, stringResourceIterator.cursor);
 
         r = (StringResource) it2.next();
@@ -165,8 +160,7 @@ public class LazyResourceCollectionTest {
 
         r = (StringResource) it1.next();
         assertEquals("r3", r.getValue());
-        assertEquals(
-                "The first iterator did not lookup in the cache for a resource",
+        assertEquals("The first iterator did not lookup in the cache for a resource",
                 3, stringResourceIterator.cursor);
 
         try {
